#!/usr/bin/env python
# -*- coding: utf-8 -*-

## Copyright (c) 2006, 2007, Joerg Zinke (team@petunial.com)
## All rights reserved.
##
## Redistribution and use in source and binary forms, with or without
## modification, are permitted provided that the following conditions
## are met:
##
##  * Redistributions of source code must retain the above copyright
##    notice, this list of conditions and the following disclaimer.
##  * Redistributions in binary form must reproduce the above copyright
##    notice, this list of conditions and the following disclaimer in
##    the documentation and/or other materials provided with the
##    distribution.
##  * Neither the name of the Petunial Team nor the names of its
##    contributors may be used to endorse or promote products derived
##    from this software without specific prior written permission.
##
## THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
## "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
## LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
## FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
## COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
## INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
## BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
## LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
## CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
## LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
## ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
## POSSIBILITY OF SUCH DAMAGE.
## added to test svn mail test4

"""

latua - setup.py

latua installation

"""

__version__ = "$Revision: 167 $"
# $URL: http://www.petunial.de/svn/latua/tags/0.1/setup.py $

## standard modules
import os
import sys
import glob
from distutils.core import setup

## latua modules
import latua

class _Install(latua.Base):
    """Installer class."""
    def __init__(self):
        latua.Base.__init__(self)
        ## initialization of system
        self.__system = latua.System()
        ## initialization of version information
        self.__version = latua.Version()

    def __keywords(self):
        """Define additional distutils keywords."""
        setup_keywords = {}
        if sys.version >= (2,5):
            ## new distutils keywords since python 2.5
            setup_keywords["requires"] = []
            if sys.platform == "win32":
                ## latua on windows requires win32 extensions
                setup_keywords["requires"] = ["pywin32"]
            setup_keywords["provides"] = ["%s (=0.1)" % (self.platform.application_name)]
            setup_keywords["obsolete"] = []
        return setup_keywords

    def run(self):
        """Run installation."""
        setup_keywords = self.__keywords()
        ## installation
        setup(name = "latua",
              version = self.__version.latua_version,
              license = self.__version.license,
              author = self.__version.author,
              author_email = self.__version.email,
              url = self.__version.url,
              download_url = self.__version.download_url,
              description = self.__version.description,
              long_description = self.__version.long_description,
              classifiers = self.__version.classifiers,
              packages = ["latua", "latua._base", "latua._system"],
              scripts = ["latua_translations", "latua_propset"],
              **setup_keywords)

## last line but first step
if __name__ == "__main__":
    installer = _Install()
    installer.run()
